@@ -473,8 +473,8 @@ class DependencyItemFile(DependencyItem):
             requesting_site_name = self.root().project().get_current_site().name()
         
         request_action = revision.request_as
-        request_action.target_site.set(requesting_site_name)
-        request_action.source_site.set(self.source_site.get())
+        request_action.sites.target_site.set(requesting_site_name)
+        request_action.sites.source_site.set(self.source_site.get())
         request_action.run(None)
 
     def compute_child_value(self, child_value):
