@@ -3,9 +3,10 @@ import os
 import fnmatch
 
 from kabaret import flow
+from kabaret.subprocess_manager.flow import RunAction
 
 from .maputils import ClearMapAction
-from kabaret.subprocess_manager.flow import RunAction
+from .users import PresetChoiceValue
 
 
 class KitsuAPIWrapper(flow.Object):
@@ -69,10 +70,16 @@ class KitsuAPIWrapper(flow.Object):
 
         return True
     
-    def get_project_data(self):
-        return gazu.project.get_project_by_name(
-            self._config.project_name.get()
-        )
+    def get_project_id(self):
+        import requests
+        try:
+            data = gazu.project.get_project_by_name(
+                self._config.project_name.get()
+            )
+        except requests.exceptions.ConnectionError:
+            return None
+        else:
+            return data['id']
     
     def get_shot_data(self, name, sequence):
         if isinstance(sequence, str):
@@ -166,9 +173,9 @@ class KitsuAPIWrapper(flow.Object):
     
     def get_user(self, project_user_name=None):
         if project_user_name is None:
-            project_user_name = self.root().project().get_user()
+            project_user_name = self.root().project().get_user_name()
         
-        user = self.root().project().get_user_from_name(project_user_name)
+        user = self.root().project().get_user(project_user_name)
         
         if user is None:
             self.root().session().log_error((
@@ -351,9 +358,9 @@ class KitsuBindings(flow.Object):
             return None
 
 
-class KitsuTaskStatus(flow.values.ChoiceValue):
+class KitsuTaskStatus(PresetChoiceValue):
     
-    STRICT_CHOICES = False
+    DEFAULT_EDITOR = 'choice'
     
     def choices(self):
         return self.root().project().kitsu_api().get_task_statutes()
