@@ -11,6 +11,7 @@ from kabaret.subprocess_manager.runner_factory import Runner, logger
 
 from ..utils.kabaret.subprocess_manager.runner_factory import Runner
 from ..utils.kabaret.subprocess_manager.flow import RunAction
+from ..resources.icons import flow as flow_icons
 
 
 CHOICES = ["blend", "kra", "png", "jpg", "txt", "abc", "mov", "psd", "aep", "zip", "mp4", "fbx", "ai", "json", "jsx", "obj"]
@@ -19,13 +20,13 @@ CHOICES_ICONS = {
             "kra": ("icons.libreflow", "krita"),
             "png": ("icons.gui", "picture"),
             "jpg": ("icons.gui", "picture"),
-            "txt": ("icons.flow", "notepad"),
+            "txt": ('icons.gui', 'text-file-1'),
             "abc": ("icons.flow", "alembic"),
             "aep": ("icons.libreflow", "afterfx"),
             "psd": ("icons.flow", "photoshop"),
             "mov": ("icons.flow", "quicktime"),
             "ai":  ("icons.libreflow", "illustrator"),
-            "zip": ("icons.flow", "file"),
+            "zip": ("icons.libreflow", "archive"),
             "mp4": ("icons.gui", "youtube-logo"),
             "fbx": ("icons.libreflow", "fbx"),
             "json": ("icons.libreflow", "json"),
