@@ -40,6 +40,7 @@ class TaskFileItem(QtWidgets.QTreeWidgetItem):
         
         if extension == 'blend':
             kwargs['use_simplify'] = (self.checkState(2) == QtCore.Qt.Checked)
+            kwargs['reduce_textures'] = (self.checkState(3) == QtCore.Qt.Checked)
         
         return self._tree.parentWidget().submit_blender_playblast_job(extension, **kwargs)
     
@@ -222,7 +223,7 @@ class ShotSelector(QtWidgets.QTreeWidget):
         self.itemChanged.connect(self.on_item_changed)
     
     def get_columns(self):
-        return ('Name', 'Revision', 'Use simplify')
+        return ('Name', 'Revision', 'Use simplify', 'Reduce textures')
     
     def on_item_changed(self, item, column):
         item.on_checkstate_toggled(column)
@@ -241,6 +242,7 @@ class ShotSelector(QtWidgets.QTreeWidget):
     def _do_refresh(self, item):
         item.setCheckState(0, QtCore.Qt.Unchecked)
         item.setCheckState(2, QtCore.Qt.Unchecked)
+        item.setCheckState(3, QtCore.Qt.Unchecked)
     
     def refresh_child(self, item):
         self._do_refresh(item)
